import { BettererFileGlobs, BettererFilePatterns, BettererTest } from '@betterer/betterer';
import { BettererCoverageDiff, BettererCoverageIssues, BettererCoverageTestFunction } from './types';
/**
 * @public `BettererCoverageTest` provides a wrapper around {@link @betterer/betterer#BettererTest | `BettererTest` }
 * that makes it easier to implement coverage tests.
 *
 * @remarks `BettererCoverageTest` provides a useful example for the more complex possibilities of the {@link @betterer/betterer#BettererTestOptions | `BettererTestOptions` }
 * interface.
 */
export declare class BettererCoverageTest extends BettererTest<BettererCoverageIssues, BettererCoverageIssues, BettererCoverageDiff> {
    private _excluded;
    private _included;
    /**
     * @internal This could change at any point! Please don't use!
     *
     * You should not construct a `BettererCoverageTest` directly.
     */
    constructor(test: BettererCoverageTestFunction, coverageSummaryPath?: string);
    /**
     * Add a list of {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions | Regular Expression } filters for files to exclude when running the test.
     *
     * @param excludePatterns - RegExp filters to match file paths that should be excluded.
     * @returns This {@link @betterer/coverage#BettererCoverageTest | `BettererCoverageTest`}, so it is chainable.
     */
    exclude(...excludePatterns: BettererFilePatterns): this;
    /**
     * Add a list of {@link https://www.npmjs.com/package/glob#user-content-glob-primer | glob }
     * patterns for files to include when running the test.
     *
     * @param includePatterns - Glob patterns to match file paths that should be included. All
     * `includes` should be relative to the {@link https://phenomnomnominal.github.io/betterer/docs/test-definition-file | test definition file}.
     * @returns This {@link @betterer/coverage#BettererCoverageTest | `BettererCoverageTest`}, so it is chainable.
     */
    include(...includePatterns: BettererFileGlobs): this;
}
//# sourceMappingURL=coverage-test.d.ts.map